//
//  OIMAnnotationView.h
//  OIMMapKitDemo
//
//  Created by songjian on 13-1-7.
//  Copyright (c) 2013年 songjian. All rights reserved.
//

#import <UIKit/UIKit.h>

//typedef NS_ENUM(NSInteger, OIMAnnotationViewDragState)
//{
//    OIMAnnotationViewDragStateNone = 0,      ///< 静止状态
//    OIMAnnotationViewDragStateStarting,      ///< 开始拖动
//    OIMAnnotationViewDragStateDragging,      ///< 拖动中
//    OIMAnnotationViewDragStateCanceling,     ///< 取消拖动
//    OIMAnnotationViewDragStateEnding         ///< 拖动结束
//};

@protocol OIMAnnotation;

/*!
 @brief 标注view
 */
@interface OIMAnnotationView : UIView

/*!
 @brief 初始化并返回一个annotation view
 @param annotation 关联的annotation对象
 @param reuseIdentifier 如果要重用view,传入一个字符串,否则设为nil,建议重用view
 @return 初始化成功则返回annotation view,否则返回nil
 */
- (id)initWithAnnotation:(id<OIMAnnotation>)annotation reuseIdentifier:(NSString *)reuseIdentifier;

/*!
 @brief 复用标识
 */
@property (nonatomic, strong, readonly) NSString *reuseIdentifier;

/*!
 @brief 当从reuse队列里取出时被调用, 子类重新必须调用super.
 */
- (void)prepareForReuse;

/*!
 @brief 关联的annotation
 */
@property (nonatomic, strong) id<OIMAnnotation> annotation;

/*!
 @brief 显示的image
 */
@property (nonatomic, strong) UIImage *image;

/*!
 @brief 默认情况下, annotation view的中心位于annotation的坐标位置，可以设置centerOffset改变view的位置，正的偏移使view朝右下方移动，负的朝左上方，单位是像素
 */
@property (nonatomic) CGPoint centerOffset;

/*!
 @brief 默认情况下, 弹出的气泡位于view正中上方，可以设置calloutOffset改变view的位置，正的偏移使view朝右下方移动，负的朝左上方，单位是像素
 */
@property (nonatomic) CGPoint calloutOffset;

/*!
 @brief 默认为YES,当为NO时view忽略触摸事件
 */
@property (nonatomic, getter=isEnabled) BOOL enabled;

@property (nonatomic, getter=isHighlighted) BOOL highlighted;

///*!
// @brief 设置是否处于选中状态, 外部如果要选中请使用mapView的selectAnnotation方法。 
// */
//@property (nonatomic, getter=isSelected) BOOL selected;
//- (void)setSelected:(BOOL)selected animated:(BOOL)animated;

//@property (nonatomic) BOOL canShowCallout;
//
///*!
// @brief 显示在气泡左侧的view
// */
//@property (strong, nonatomic) UIView *leftCalloutAccessoryView;
//
///*!
// @brief 显示在气泡右侧的view
// */
//@property (strong, nonatomic) UIView *rightCalloutAccessoryView;
//
///*!
// @brief 是否支持拖动
// */
//@property (nonatomic, getter=isDraggable) BOOL draggable NS_AVAILABLE(NA, 4_0);
//
///*!
// @brief 当前view的拖动状态
// */
//@property (nonatomic) OIMAnnotationViewDragState dragState NS_AVAILABLE(NA, 4_0);
//- (void)setDragState:(OIMAnnotationViewDragState)newDragState animated:(BOOL)animated NS_AVAILABLE(NA, 4_2);

@end
